#ifndef NT2_INCLUDE_FUNCTIONS_ISVECTORALONG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISVECTORALONG_HPP_INCLUDED

#include <nt2/predicates/include/functions/isvectoralong.hpp>

#endif
